@@ -10,6 +10,8 @@
 
 #include "akregator_export.h"
 #include "article.h"
+#include "articlematcher.h"
+
 #include <QWidget>
 
 #include <QPointer>
@@ -23,10 +25,6 @@ class KActionCollection;
 
 namespace Akregator
 {
-namespace Filters
-{
-class AbstractMatcher;
-}
 
 class ArticleFormatter;
 class ArticleListJob;
@@ -113,7 +111,7 @@ private:
     QSharedPointer<ArticleFormatter> normalViewFormatter();
     void keyPressEvent(QKeyEvent *e) override;
 
-    /** renders @c body. Use this method whereever possible.
+    /** renders @c body. Use this method wherever possible.
      *  @param body html to render, without header and footer */
     void renderContent(const QString &body);
 
@@ -146,4 +144,3 @@ private:
     const QString m_grantleeDirectory;
 };
 } // namespace Akregator
-
